@@ -843,6 +843,34 @@ class TestWebExtensionStore(test_monolingual.TestMonolingualStore):
 
         assert out.getvalue() == DATA
 
+    def test_comments(self):
+        DATA = """{
+    "test": {
+        // Comment
+        "message": "Message //"
+    },
+    "test//": { // Comment
+        "message": "Message // Other"
+    }
+}
+"""
+        store = self.StoreClass()
+        store.parse(DATA)
+        assert len(store.units) == 2
+        # Any comments will be stripped
+        assert (
+            bytes(store).decode()
+            == """{
+    "test": {
+        "message": "Message //"
+    },
+    "test//": {
+        "message": "Message // Other"
+    }
+}
+"""
+        )
+
 
 class TestI18NextStore(test_monolingual.TestMonolingualStore):
     StoreClass = jsonl10n.I18NextFile
@@ -1416,13 +1444,29 @@ class TestARBJsonFile(test_monolingual.TestMonolingualStore):
     def test_leading_dot_keys(self):
         jsontext = """{
   ".dot": "dot",
-  "@.dot": {}
+  "@.dot": {},
+  "nav:colon": "colon in a colon",
+  "@nav:colon": {}
 }
 """
         store = self.StoreClass()
         store.parse(jsontext)
+        assert len(store.units) == 2
+        store.units[1].target = "colon in a colon"
         assert bytes(store).decode() == jsontext
 
+    def test_invalid_nesting(self):
+        jsontext = """{
+    "key": {
+        ".dot": "dot",
+        "@.dot": {}
+    }
+}
+"""
+        store = self.StoreClass()
+        with raises(base.ParseError):
+            store.parse(jsontext)
+
 
 JSON_FORMATJS = """{
     "hak27d": {
@@ -1470,3 +1514,12 @@ class TestFormatJSJsonFile(test_monolingual.TestMonolingualStore):
         store = self.StoreClass()
         store.parse(jsontext)
         assert bytes(store).decode() == jsontext
+
+    def test_invalid(self):
+        jsontext = """{
+    ".dot": "text"
+}
+"""
+        store = self.StoreClass()
+        with raises(base.ParseError):
+            store.parse(jsontext)
