@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert Symbian localisation files to Gettext PO localization files.
+"""
+Convert Symbian localisation files to Gettext PO localization files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/symb2po.html
 for examples and usage instructions.
@@ -82,8 +83,7 @@ def get_template_dict(template_file):
     if template_file is not None:
         template_header, template_units = read_symbian(template_file)
         return template_header, dict(template_units)
-    else:
-        return {}, {}
+    return {}, {}
 
 
 def build_output(units, template_header, template_dict):
@@ -115,9 +115,8 @@ def convert_symbian(
 
     if output_store.isempty():
         return 0
-    else:
-        output_store.serialize(output_file)
-        return 1
+    output_store.serialize(output_file)
+    return 1
 
 
 def main(argv=None):
