@@ -291,9 +291,7 @@ class dtdunit(base.TranslationUnit):
         return self.entity is None
 
     def istranslatable(self):
-        if getattr(self, "entityparameter", None) == "SYSTEM" or self.isblank():
-            return False
-        return True
+        return getattr(self, "entityparameter", None) != "SYSTEM" and not self.isblank()
 
     def parse(self, dtdsrc):
         """Read the first dtd element from the source code into this object, return linesprocessed."""
@@ -340,7 +338,7 @@ class dtdunit(base.TranslationUnit):
                         # plain comment
                         self.commenttype = "comment"
                 # FIXME: bloody entity might share a line with something important
-                elif not self.inentity and re.search("%.*;", line):
+                elif not self.inentity and re.search(r"%[^;%]+;", line):
                     # now work out the type of comment, and save it (remember we're not in the comment yet)
                     self.comments.append(("comment", line))
                     line = ""
@@ -447,7 +445,7 @@ class dtdunit(base.TranslationUnit):
                     e = 0
                     if not line:
                         continue
-                    if line[0] in ('"', "'"):
+                    if line[0] in {'"', "'"}:
                         self.entitypart = "definition"
                         self.entityhelp = (e, line[e])
                         self.instring = False
@@ -608,9 +606,9 @@ class dtdfile(base.TranslationStore):
         # Android files are invalid DTDs
         if not self.android:
             # #expand is a Mozilla hack and are removed as they are not valid in DTDs
-            _input = re.sub(b"#expand", b"", content)
+            input_ = re.sub(rb"#expand", b"", content)
             try:
-                etree.DTD(BytesIO(_input))
+                etree.DTD(BytesIO(input_))
             except etree.DTDParseError as e:
                 warnings.warn(f"DTD parse error: {e.error_log}")
                 return False
